bayespy.inference.vmp.nodes.wishart.WishartDistribution.plates_from_parent
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.wishart

.. automethod:: WishartDistribution.plates_from_parent